<?php
/**
 * Theme functions file
 *
 * Contains all of the Theme's setup functions, custom functions,
 * custom hooks and Theme settings.
 *
 * @package    Shopy
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'shopy_content_width' ) ) :
/**
 * Set new content width if user uses 1 column layout.
 *
 * @since  1.0.0
 */
function shopy_content_width() {
	global $content_width;

	if ( in_array( get_theme_mod( 'theme_layout' ), array( '1c' ) ) ) {
		$content_width = 960;
	}
}
endif;
add_action( 'template_redirect', 'shopy_content_width' );

if ( ! function_exists( 'shopy_theme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * @since  1.0.0
 */
function shopy_theme_setup() {

	// Make the theme available for translation.
	load_theme_textdomain( 'shopy', trailingslashit( get_template_directory() ) . 'languages' );

	// Add custom stylesheet file to the TinyMCE visual editor.
	add_editor_style( array( 'assets/css/editor-style.css', shopy_nunito_font_url(), shopy_kameron_font_url() ) );

	// Add RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	// Enable support for Post Thumbnails.
	add_theme_support( 'post-thumbnails' );

	// Declare image sizes.
	add_image_size( 'shopy-banner', 340, 200, true );
	add_image_size( 'shopy-slider', 1060, 550, true );

	// Register custom navigation menu.
	register_nav_menus(
		array(
			'top'       => __( 'Top Location', 'shopy' ),
			'primary'   => __( 'Primary Location', 'shopy' )
		)
	);

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-list', 'search-form', 'comment-form', 'gallery', 'caption'
	) );

	/*
	 * Enable support for Post Formats.
	 * See: http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'audio', 'gallery', 'image', 'link', 'video'
	) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'shopy_custom_background_args', array(
		'default-color' => 'ffffff'
	) ) );

	// Enable theme-layouts extensions.
	add_theme_support( 'theme-layouts',
		array(
			'1c'   => __( '1 Column Wide (Full Width)', 'shopy' ),
			'2c-l' => __( '2 Columns: Content / Sidebar', 'shopy' ),
			'2c-r' => __( '2 Columns: Sidebar / Content', 'shopy' )
		),
		array( 'customize' => false, 'default' => '2c-l' )
	);

	// This theme uses its own gallery styles.
	add_filter( 'use_default_gallery_style', '__return_false' );

	// Declare WooCommerce support
	add_theme_support( 'woocommerce' );

	// Support WooCommerce 3.0
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );


}
endif; // shopy_theme_setup
add_action( 'after_setup_theme', 'shopy_theme_setup' );

if ( ! function_exists( 'shopy_reset_default_image_sizes' ) ) :
/**
 * Re-set default image sizes
 *
 * @since  1.0.0
 */
function shopy_reset_default_image_sizes() {
	// 'large' size
	update_option( 'large_size_w', 1024 );
	update_option( 'large_size_h', 568 );
	update_option( 'large_crop', 1 );

	// 'medium' size
	update_option( 'medium_size_w', 350 );
	update_option( 'medium_size_h', 210 );
	update_option( 'medium_crop', 1 );
}
endif;
add_action( 'after_switch_theme', 'shopy_reset_default_image_sizes' );

/**
 * Registers custom widgets.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_widget
 */
function shopy_widgets_init() {

	// Register ad widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-ads.php';
	register_widget( 'Shopy_Ads_Widget' );

	// Register feedburner widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-feedburner.php';
	register_widget( 'Shopy_Feedburner_Widget' );

	// Register recent posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-recent.php';
	register_widget( 'Shopy_Recent_Widget' );

	// Register popular posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-popular.php';
	register_widget( 'Shopy_Popular_Widget' );

	// Register random posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-random.php';
	register_widget( 'Shopy_Random_Widget' );

	// Register most views posts thumbnail widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-views.php';
	register_widget( 'Shopy_Views_Widget' );

	// Register twitter widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-twitter.php';
	register_widget( 'Shopy_Twitter_Widget' );

	// Register social widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-social.php';
	register_widget( 'Shopy_Social_Widget' );

	// Register facebook widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-facebook.php';
	register_widget( 'Shopy_Facebook_Widget' );

	// Register video widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-video.php';
	register_widget( 'Shopy_Video_Widget' );

	// Register banner widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-home-banner.php';
	register_widget( 'Shopy_Banner_Widget' );

	// Register slider widget.
	require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-home-slider.php';
	register_widget( 'Shopy_Slider_Widget' );

	if ( is_woocommerce_activated() ) {
		// Register recent products widget.
		require trailingslashit( get_template_directory() ) . 'inc/widgets/widget-home-products.php';
		register_widget( 'Shopy_Products_Widget' );
	}

}
add_action( 'widgets_init', 'shopy_widgets_init' );

/**
 * Registers widget areas and custom widgets.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function shopy_sidebars_init() {

	register_sidebar(
		array(
			'name'          => __( 'Front Page', 'shopy' ),
			'id'            => 'front-page',
			'description'   => __( 'Sidebar to customize your content on front page.', 'shopy' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title"><span>',
			'after_title'   => '</span></h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Primary', 'shopy' ),
			'id'            => 'primary',
			'description'   => __( 'Main sidebar that appears on the right.', 'shopy' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 1', 'shopy' ),
			'id'            => 'footer-1',
			'description'   => __( 'The footer sidebar 1st column.', 'shopy' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 2', 'shopy' ),
			'id'            => 'footer-2',
			'description'   => __( 'The footer sidebar 2nd column.', 'shopy' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 3', 'shopy' ),
			'id'            => 'footer-3',
			'description'   => __( 'The footer sidebar 3rd column.', 'shopy' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 4', 'shopy' ),
			'id'            => 'footer-4',
			'description'   => __( 'The footer sidebar 4th column.', 'shopy' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

	register_sidebar(
		array(
			'name'          => __( 'Footer 5', 'shopy' ),
			'id'            => 'footer-5',
			'description'   => __( 'The footer sidebar 5th column.', 'shopy' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);

}
add_action( 'widgets_init', 'shopy_sidebars_init' );

/**
 * Register Nunito Google font.
 *
 * @since  1.0.0
 * @return string
 */
function shopy_nunito_font_url() {

	$font_url = '';
	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Nunito, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Nunito font: on or off', 'shopy' ) ) {
		$font_url = add_query_arg( 'family', urlencode( 'Nunito:300,400,700' ), "//fonts.googleapis.com/css" );
	}

	return $font_url;
}

/**
 * Register Kameron Google font.
 *
 * @since  1.0.0
 * @return string
 */
function shopy_kameron_font_url() {

	$font_url = '';
	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Kameron, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Kameron font: on or off', 'shopy' ) ) {
		$font_url = add_query_arg( 'family', urlencode( 'Kameron:400,700' ), "//fonts.googleapis.com/css" );
	}

	return $font_url;
}

if ( ! function_exists( 'is_woocommerce_activated' ) ) :
/**
 * Query WooCommerce activation
 *
 * @since  1.0.0
 */
function is_woocommerce_activated() {
	return class_exists( 'woocommerce' ) ? true : false;
}
endif;

if ( ! function_exists( 'is_polylang_activated' ) ) :
/**
 * Query Polylang activation
 *
 * @since  1.0.0
 */
function is_polylang_activated() {
	return function_exists( 'pll_the_languages' ) ? true : false;
}
endif;

/**
 * Custom template tags for this theme.
 */
require trailingslashit( get_template_directory() ) . 'inc/template-tags.php';

/**
 * Enqueue scripts and styles.
 */
require trailingslashit( get_template_directory() ) . 'inc/scripts.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require trailingslashit( get_template_directory() ) . 'inc/extras.php';

/**
 * Require and recommended plugins list.
 */
require trailingslashit( get_template_directory() ) . 'inc/plugins.php';

/**
 * Load Jetpack compatibility file.
 */
require trailingslashit( get_template_directory() ) . 'inc/jetpack.php';

/**
 * Load WooCommerce compatibility file.
 */
if ( is_woocommerce_activated() ) {
	require trailingslashit( get_template_directory() ) . 'inc/woocommerce/woocommerce.php';
	require trailingslashit( get_template_directory() ) . 'inc/woocommerce/hooks.php';
	require trailingslashit( get_template_directory() ) . 'inc/woocommerce/template-tags.php';
}

/**
 * Customizer.
 */
require trailingslashit( get_template_directory() ) . 'admin/customizer-library.php';
require trailingslashit( get_template_directory() ) . 'admin/functions.php';

/**
 * Customizer functions.
 */
require trailingslashit( get_template_directory() ) . 'inc/customizer.php';
require trailingslashit( get_template_directory() ) . 'inc/mods.php';

/**
 * We use some part of Hybrid Core to extends our themes.
 *
 * @link  http://themehybrid.com/hybrid-core Hybrid Core site.
 */
require trailingslashit( get_template_directory() ) . 'inc/hybrid/attr.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/breadcrumb-trail.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/theme-layouts.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/entry-views.php';
require trailingslashit( get_template_directory() ) . 'inc/hybrid/hybrid-media-grabber.php';

/**
 * Load Polylang compatibility file.
 */
if ( ( function_exists( 'is_polylang_activated' ) && ( is_polylang_activated() ) ) ) {
	require trailingslashit( get_template_directory() ) . 'inc/polylang.php';
}

// MailOptin integration
require get_template_directory() . '/inc/mailoptin.php';
