<?php
/**
 * Custom functions that act independently of the theme templates
 *
 * Eventually, some of the functionality here could be replaced by core features
 *
 * @package    Shopy
 * @author     Theme Junkie
 * @copyright  Copyright (c) 2015, Theme Junkie
 * @license    http://www.gnu.org/licenses/gpl-2.0.html
 * @since      1.0.0
 */

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 *
 * @since  1.0.0
 * @param  array $args Configuration arguments.
 * @return array
 */
function shopy_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'shopy_page_menu_args' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the body element.
 * @return array
 */
function shopy_body_classes( $classes ) {

	// Theme prefix
	$prefix = 'shopy-';

	// Adds a class of multi-author to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'multi-author';
	}

	// Boxed / fullwidth style class.
	$style = shopy_mod( $prefix . 'boxed-fullwidth' );
	if ( $style == 'boxed' ) {
		$classes[] = 'boxed';
	} else {
		$classes[] = 'fullwidth';
	}

	// Header style class.
	$style = shopy_mod( $prefix . 'header-style' );
	if ( $style == 'one' ) {
		$classes[] = 'header-style-one';
	} elseif ( $style == 'two' ) {
		$classes[] = 'header-style-two';
	} elseif ( $style == 'three' ) {
		$classes[] = 'header-style-three';
	} else {
		$classes[] = 'header-style-four';
	}

	// Footer style class.
	$style = shopy_mod( $prefix . 'footer-style' );
	if ( $style == 'one' ) {
		$classes[] = 'footer-style-one';
	} else {
		$classes[] = 'footer-style-two';
	}

	return $classes;
}
add_filter( 'body_class', 'shopy_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 *
 * @since  1.0.0
 * @param  array $classes Classes for the post element.
 * @return array
 */
function shopy_post_classes( $classes ) {

	// Adds a class if a post hasn't a thumbnail.
	if ( ! has_post_thumbnail() ) {
		$classes[] = 'no-post-thumbnail';
	}

	if ( function_exists( 'yith_wishlist_constructor' ) ) {
		if ( 'product' == get_post_type() ) {
			$classes[] = 'yith-wishlist';
		}
	}

	return $classes;
}
add_filter( 'post_class', 'shopy_post_classes' );

if ( version_compare( $GLOBALS['wp_version'], '4.1', '<' ) ) :
	/**
	 * Filters wp_title to print a neat <title> tag based on what is being viewed.
	 *
	 * @param string $title Default title text for current view.
	 * @param string $sep Optional separator.
	 * @return string The filtered title.
	 */
	function shopy_wp_title( $title, $sep ) {
		if ( is_feed() ) {
			return $title;
		}

		global $page, $paged;

		// Add the blog name
		$title .= get_bloginfo( 'name', 'display' );

		// Add the blog description for the home/front page.
		$site_description = get_bloginfo( 'description', 'display' );
		if ( $site_description && ( is_home() || is_front_page() ) ) {
			$title .= " $sep $site_description";
		}

		// Add a page number if necessary:
		if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
			$title .= " $sep " . sprintf( __( 'Page %s', 'shopy' ), max( $paged, $page ) );
		}

		return $title;
	}
	add_filter( 'wp_title', 'shopy_wp_title', 10, 2 );

	/**
	 * Title shim for sites older than WordPress 4.1.
	 *
	 * @link https://make.wordpress.org/core/2014/10/29/title-tags-in-4-1/
	 * @todo Remove this function when WordPress 4.3 is released.
	 */
	function shopy_render_title() {
		?>
		<title><?php wp_title( '|', true, 'right' ); ?></title>
		<?php
	}
	add_action( 'wp_head', 'shopy_render_title' );
endif;

/**
 * Change the excerpt more string.
 *
 * @since  1.0.0
 * @param  string  $more
 * @return string
 */
function shopy_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'shopy_excerpt_more' );

/**
 * Remove theme-layouts meta box on attachment and bbPress post type.
 * 
 * @since 1.0.0
 */
function shopy_remove_theme_layout_metabox() {
	remove_post_type_support( 'attachment', 'theme-layouts' );
	remove_post_type_support( 'forum', 'theme-layouts' );
	remove_post_type_support( 'topic', 'theme-layouts' );
	remove_post_type_support( 'reply', 'theme-layouts' );
}
add_action( 'init', 'shopy_remove_theme_layout_metabox', 11 );

/**
 * Extend archive title
 *
 * @since  1.0.0
 */
function shopy_extend_archive_title( $title ) {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = single_tag_title( '', false );
	} elseif ( is_author() ) {
		$title = get_the_author();
	}
	return $title;
}
add_filter( 'get_the_archive_title', 'shopy_extend_archive_title' );

/**
 * Add post type 'post' support for the Simple Page Sidebars plugin.
 * 
 * @since  1.0.0
 */
function shopy_page_sidebar_plugin() {
	if ( class_exists( 'Simple_Page_Sidebars' ) ) {
		add_post_type_support( 'post', 'simple-page-sidebars' );
	}
}
add_action( 'init', 'shopy_page_sidebar_plugin' );

/**
 * Customize tag cloud widget
 *
 * @since  1.0.0
 */
function shopy_customize_tag_cloud( $args ) {
	$args['largest']  = 12;
	$args['smallest'] = 12;
	$args['unit']     = 'px';
	$args['number']   = 20;
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'shopy_customize_tag_cloud' );
add_filter( 'woocommerce_product_tag_cloud_widget_args', 'shopy_customize_tag_cloud' );

/**
 * Add custom fields to the author profile fields
 *
 * @since  1.0.0
 */
function shopy_new_contactmethods( $contactmethods ) {
	$contactmethods['twitter']   = 'Twitter';
	$contactmethods['facebook']  = 'Facebook';
	$contactmethods['gplus']     = 'Google Plus';
	$contactmethods['instagram'] = 'Instagram';
	$contactmethods['linkedin']  = 'Linkedin';

	// Remove default contacts
	unset( $contactmethods['aim'] );
	unset( $contactmethods['jabber'] );
	unset( $contactmethods['yim'] );

	// Display the new fields
	return $contactmethods;
}
add_filter( 'user_contactmethods', 'shopy_new_contactmethods', 10, 1 );

/**
 * Home layout
 *
 * @since  1.0.0
 */
function shopy_layout( $layout ) {

	if ( is_page_template( 'page-templates/home.php' ) || is_page_template( 'page-templates/blog-full.php' ) || is_page_template( 'page-templates/blog-masonry.php' ) ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = '1c';
		}
	}

	if ( is_page_template( 'page-templates/blog-left-sidebar.php' ) ) {
		$post_layout = get_post_layout( get_queried_object_id() );
		if ( 'default' === $post_layout ) {
			$layout = '2c-r';
		}
	}

	return $layout;
}
add_filter( 'theme_mod_theme_layout', 'shopy_layout', 15 );